Appearance
Interface: XULElementProps
Defined in: src/tools/ui.ts:542
Extends
Exclude<ElementProps, {tag:any; }>
Properties
attributes?
ts
optional attributes: object;Defined in: src/tools/ui.ts:473
Set with elem.setAttribute()
Index Signature
ts
[key: string]: undefined | null | string | number | booleanInherited from
ts
Exclude.attributes;checkExistenceParent?
ts
optional checkExistenceParent: HTMLElement;Defined in: src/tools/ui.ts:505
Existence check will be processed under this element, default document
Inherited from
ts
Exclude.checkExistenceParent;children?
ts
optional children: TagElementProps[];Defined in: src/tools/ui.ts:489
Child elements. Will be created and appended to this element.
Inherited from
ts
Exclude.children;classList?
ts
optional classList: string[];Defined in: src/tools/ui.ts:455
classList
Inherited from
ts
Exclude.classList;customCheck()?
ts
optional customCheck: (doc, options) => boolean;Defined in: src/tools/ui.ts:511
Custom check hook. If it returns false, return undefined and do not do anything.
Parameters
doc
Document
options
Returns
boolean
Inherited from
ts
Exclude.customCheck;directAttributes?
ts
optional directAttributes: object;Defined in: src/tools/ui.ts:467
Index Signature
ts
[key: string]: undefined | null | string | number | booleanDeprecated
Use properties
Inherited from
ts
Exclude.directAttributes;enableElementDOMLog?
ts
optional enableElementDOMLog: boolean;Defined in: src/tools/ui.ts:527
Enable elements to be printed to console & Zotero.debug.
Inherited from
ts
Exclude.enableElementDOMLog;enableElementJSONLog?
ts
optional enableElementJSONLog: boolean;Defined in: src/tools/ui.ts:523
Enable elements to be printed to console & Zotero.debug.
Inherited from
ts
Exclude.enableElementJSONLog;enableElementRecord?
ts
optional enableElementRecord: boolean;Defined in: src/tools/ui.ts:519
Enable elements to be recorded by the toolkit so it can be removed when calling unregisterAll.
Inherited from
ts
Exclude.enableElementRecord;id?
ts
optional id: string;Defined in: src/tools/ui.ts:447
id
Inherited from
ts
Exclude.id;ignoreIfExists?
ts
optional ignoreIfExists: boolean;Defined in: src/tools/ui.ts:493
Set true to check if the element exists using id. If exists, return this element and do not do anything.
Inherited from
ts
Exclude.ignoreIfExists;listeners?
ts
optional listeners: object[];Defined in: src/tools/ui.ts:477
Event listeners
listener
ts
listener: undefined | null | EventListenerOrEventListenerObject | (e) => void;options?
ts
optional options: boolean | AddEventListenerOptions;type
ts
type: string;Inherited from
ts
Exclude.listeners;namespace?
ts
optional namespace: "xul";Defined in: src/tools/ui.ts:543
xul | html | svg
Overrides
ts
Exclude.namespace;properties?
ts
optional properties: object;Defined in: src/tools/ui.ts:463
Set with elem.prop =
Index Signature
ts
[key: string]: unknownInherited from
ts
Exclude.properties;removeIfExists?
ts
optional removeIfExists: boolean;Defined in: src/tools/ui.ts:501
Set true to check if the element exists using id. If exists, remove and re-create it, then continue with props/attrs/children.
Inherited from
ts
Exclude.removeIfExists;skipIfExists?
ts
optional skipIfExists: boolean;Defined in: src/tools/ui.ts:497
Set true to check if the element exists using id. If exists, skip element creation and continue with props/attrs/children.
Inherited from
ts
Exclude.skipIfExists;styles?
ts
optional styles: Partial<CSSStyleDeclaration>;Defined in: src/tools/ui.ts:459
styles
Inherited from
ts
Exclude.styles;subElementOptions?
ts
optional subElementOptions: TagElementProps[];Defined in: src/tools/ui.ts:515
Deprecated
Use children
Inherited from
ts
Exclude.subElementOptions;tag?
ts
optional tag: string;Defined in: src/tools/ui.ts:443
tagName
Inherited from
ts
Exclude.tag;