Appearance
Interface: TagElementProps
Defined in: src/tools/ui.ts:530
props of UITool.createElement. See UITool
Extends
Properties
attributes?
ts
optional attributes: object;Defined in: src/tools/ui.ts:473
Set with elem.setAttribute()
Index Signature
ts
[key: string]: undefined | null | string | number | booleanInherited from
checkExistenceParent?
ts
optional checkExistenceParent: HTMLElement;Defined in: src/tools/ui.ts:505
Existence check will be processed under this element, default document
Inherited from
ElementProps.checkExistenceParent
children?
ts
optional children: TagElementProps[];Defined in: src/tools/ui.ts:489
Child elements. Will be created and appended to this element.
Inherited from
classList?
ts
optional classList: string[];Defined in: src/tools/ui.ts:455
classList
Inherited from
customCheck()?
ts
optional customCheck: (doc, options) => boolean;Defined in: src/tools/ui.ts:511
Custom check hook. If it returns false, return undefined and do not do anything.
Parameters
doc
Document
options
Returns
boolean
Inherited from
directAttributes?
ts
optional directAttributes: object;Defined in: src/tools/ui.ts:467
Index Signature
ts
[key: string]: undefined | null | string | number | booleanDeprecated
Use properties
Inherited from
enableElementDOMLog?
ts
optional enableElementDOMLog: boolean;Defined in: src/tools/ui.ts:527
Enable elements to be printed to console & Zotero.debug.
Inherited from
ElementProps.enableElementDOMLog
enableElementJSONLog?
ts
optional enableElementJSONLog: boolean;Defined in: src/tools/ui.ts:523
Enable elements to be printed to console & Zotero.debug.
Inherited from
ElementProps.enableElementJSONLog
enableElementRecord?
ts
optional enableElementRecord: boolean;Defined in: src/tools/ui.ts:519
Enable elements to be recorded by the toolkit so it can be removed when calling unregisterAll.
Inherited from
ElementProps.enableElementRecord
id?
ts
optional id: string;Defined in: src/tools/ui.ts:447
id
Inherited from
ignoreIfExists?
ts
optional ignoreIfExists: boolean;Defined in: src/tools/ui.ts:493
Set true to check if the element exists using id. If exists, return this element and do not do anything.
Inherited from
listeners?
ts
optional listeners: object[];Defined in: src/tools/ui.ts:477
Event listeners
listener
ts
listener: undefined | null | EventListenerOrEventListenerObject | (e) => void;options?
ts
optional options: boolean | AddEventListenerOptions;type
ts
type: string;Inherited from
namespace?
ts
optional namespace: string;Defined in: src/tools/ui.ts:451
xul | html | svg
Inherited from
properties?
ts
optional properties: object;Defined in: src/tools/ui.ts:463
Set with elem.prop =
Index Signature
ts
[key: string]: unknownInherited from
removeIfExists?
ts
optional removeIfExists: boolean;Defined in: src/tools/ui.ts:501
Set true to check if the element exists using id. If exists, remove and re-create it, then continue with props/attrs/children.
Inherited from
skipIfExists?
ts
optional skipIfExists: boolean;Defined in: src/tools/ui.ts:497
Set true to check if the element exists using id. If exists, skip element creation and continue with props/attrs/children.
Inherited from
styles?
ts
optional styles: Partial<CSSStyleDeclaration>;Defined in: src/tools/ui.ts:459
styles
Inherited from
subElementOptions?
ts
optional subElementOptions: TagElementProps[];Defined in: src/tools/ui.ts:515
Deprecated
Use children
Inherited from
ElementProps.subElementOptions
tag
ts
tag: string;Defined in: src/tools/ui.ts:531
tagName